@@ -1,10 +1,14 @@
 from .__version__ import __version__
 from ._parser import parse_path, path_to_string
-from ._transform import translate_and_scale
+from ._translate_and_scale import translate_and_scale
+from ._segmentize import segmentize
+from ._morph import morph
 
 __all__ = [
     '__version__',
     'parse_path',
     'path_to_string',
     'translate_and_scale',
+    'segmentize',
+    'morph',
     ]
