@@ -1,8 +1,10 @@
 import sys
 import argparse
+import traceback
 from lark import LarkError
 from ._parser import parse_path, path_to_string
-from ._transform import translate_and_scale
+from ._translate_and_scale import translate_and_scale
+from ._segmentize import segmentize
 from .__version__ import __version__
 
 
@@ -15,15 +17,18 @@ def _main():
     arg('--sy', metavar='N', type=float, default=1., help='scale y by N')
     arg('--sfig', metavar='N', type=int, default=5, help='round to N significant figures')
     arg('--ndig', metavar='N', type=int, default=None, help='round to N decimal places')
+    arg('--seg', metavar='N', type=float, default=None, help='convert to line segments with given max distance')
     arg('-v', '--version', action='version', version=f'%(prog)s {__version__}')
     args = parser.parse_args()
     try:
         d = parse_path(sys.stdin.read())
-        p = translate_and_scale(d, (args.dx, args.dy), (args.sx, args.sy))
+        if args.seg is not None:
+            d = segmentize(d, args.seg)
+        d = translate_and_scale(d, (args.dx, args.dy), (args.sx, args.sy))
     except LarkError:
         print('Invalid path data', file=sys.stderr)
         return 1
-    except Exception as e:
-        print(e, file=sys.stderr)
+    except Exception:
+        traceback.print_exc()
         return 1
-    print(path_to_string(p, args.sfig, args.ndig))
+    print(path_to_string(d, args.sfig, args.ndig))
